@@ -1,5 +1,5 @@
 package TestClass;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 
 use Moose;
@@ -7,10 +7,12 @@ use MooseX::MethodAttributes;
 
 sub foo : SomeAttribute AnotherAttribute('with argument') {}
 
+sub bar : SomeAttribute {}
+
 after foo => sub {};
 
 package SubClass;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 
 use Moose;
@@ -20,4 +22,6 @@ extends qw/TestClass/;
 
 sub foo : Attributes Attributes Attributes {}
 
+sub bar {}  # no attribute!
+
 1;
